@@ -16,6 +16,7 @@
 #' @param session The shiny session object for the application.
 #' @param input shiny server input
 #' @param output shiny server output
+#' @param debug enable debugging mode
 #' @return None
 
 #' @examples
@@ -23,18 +24,44 @@
 #' runCNVScopeShiny()
 #' }
 #' @export
-globalVariables(c("ensembl_gene_tx_data_gr","baseurl","chromosomes","downsample_factor","basefn",
-                  "subset_name",
-                  "expression_data_gr_nbl",'start2','start1','value','Var1','Var2','value1',
-                  'tcga_type','census_data_gr','common_coords','myReactives',
-                  'genev','delete.isolates','freq_data'))
-downsample_factor<-NULL
-subset_name<-NULL
-expression_data_gr_nbl<-NULL
-tcga_type<-NULL
-chrom.pairs<-NULL
-CNVScopeserver<-function(session,input, output) {
-  if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
+#globalVariables(c("ensembl_gene_tx_data_gr","baseurl","chromosomes","downsample_factor","basefn",
+#                  "subset_name",
+#                  "expression_data_gr_nbl",'start2','start1','value','Var1','Var2','value1',
+#                 'tcga_type','census_data_gr','common_coords','myReactives',
+#                  'genev','delete.isolates','freq_data'),add = F)
+if(getRversion() >= "2.15.1")  utils::globalVariables(c("."), add=F)
+CNVScopeserver<-function(session,input, output, debug=F) {
+ensembl_gene_tx_data_gr <- if(exists("ensembl_gene_tx_data_gr")){get("ensembl_gene_tx_data_gr")} else {NULL}
+baseurl <- if(exists("baseurl")){get("baseurl")} else {NULL}
+basefn <- if(exists("basefn")){get("basefn")} else {NULL}
+start1 <- if(exists("start1")){get("start1")} else {NULL}
+start2 <- if(exists("start2")){get("start2")} else {NULL}
+value <- if(exists("value")){get("value")} else {NULL}
+value1 <- if(exists("value1")){get("value1")} else {NULL}
+Var1 <- if(exists("Var1")){get("Var1")} else {NULL}
+Var2 <- if(exists("Var2")){get("Var2")} else {NULL}
+bins.seqnames <- if(exists("bins.seqnames")){get("bins.seqnames")} else {NULL}
+bins.start <- if(exists("bins.start")){get("bins.start")} else {NULL}
+bins.end <- if(exists("bins.end")){get("bins.end")} else {NULL}
+expression_data_gr <- if(exists("expression_data_gr")){get("expression_data_gr")} else {NULL}
+common_coords <- if(exists("common_coords")){get("common_coords")} else {NULL}
+myReactives <- if(exists("myReactives")){get("myReactives")} else {NULL}
+genev <- if(exists("genev")){get("genev")} else {NULL}
+delete.isolates <- function(graph, mode = 'all') {
+  isolates <- which(igraph::degree(graph, mode = mode) == 0) 
+  delete.vertices(graph, isolates)
+}
+freq_data <- if(exists("freq_data")){get("freq_data")} else {NULL}
+
+  privpolurl <- a("NCI Privacy Policy", href="https://www.cancer.gov/policies/privacy-security",target="_blank")
+  output$privpol <- renderUI({
+    tagList(privpolurl)})
+  downsample_factor<-NULL
+  subset_name<-NULL
+  #expression_data_gr_nbl<-NULL
+  tcga_type<-NULL
+  chrom.pairs<-NULL
+  
   
   printLogJs <- function(x, ...) {
     
@@ -147,27 +174,27 @@ CNVScopeserver<-function(session,input, output) {
     
     
     if(isolate(input$data_source)=="linreg_osteosarcoma_CNVkit")
-    {     load( url(paste0(paste0(baseurl,"plotly_dashboard_ext/matrix/linreg/unrescaled/",
+    {     load( url(paste0(paste0(baseurl,"matrix/linreg/unrescaled/",
                                   chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom1))))],chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom2))))],
                                   "melted_downsampled_linreg_unrescaled.RData"))))
       
-      load( url(paste0(paste0(baseurl,"plotly_dashboard_ext/matrix/linreg/unrescaled/full/",
+      load( url(paste0(paste0(baseurl,"matrix/linreg/unrescaled/full/",
                               chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom1))))],chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom2))))],
                               "melted_full_linreg_max_cap_75.RData"))))
       #browser()
       downsample_factor<<-4
-      tryCatch(bin_data<-readRDS((url(paste0(baseurl,"plotly_dashboard_ext/bin_data.rds")))),error = function(e) NULL) 
-      tryCatch(bin_data<-readRDS((paste0(basefn,"plotly_dashboard_ext/bin_data.rds"))),error = function(e) NULL) 
+      tryCatch(bin_data<-readRDS((url(paste0(baseurl,"bin_data.rds")))),error = function(e) NULL) 
+      tryCatch(bin_data<-readRDS((paste0(basefn,"bin_data.rds"))),error = function(e) NULL) 
       
     }
     # 
     if(isolate(input$data_source)=="TCGA_SARC_SNP6")
     {
-      load( url(paste0(paste0(baseurl,"plotly_dashboard_ext/matrix/TCGA_SARC/downsampled_factor_8/",
+      load( url(paste0(paste0(baseurl,"matrix/TCGA_SARC/downsampled_factor_8/",
                               chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom1))))],chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom2))))],
                               "melted_downsampled_TGCA_SARC_unrescaledv2.RData"))))
       
-      # load( url(paste0(paste0(baseurl,"plotly_dashboard_ext/matrix/TCGA_SARC/full/",
+      # load( url(paste0(paste0(baseurl,"matrix/TCGA_SARC/full/",
       #                  chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom1))))],chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom2))))],
       #                  "melted_full_TGCA_SARC_unrescaled.RData"))))
       downsample_factor<<-8
@@ -177,7 +204,7 @@ CNVScopeserver<-function(session,input, output) {
     {
       #
       sample_name<-"BRCA_output_matrix1e6"
-      load( url(paste0(paste0(baseurl,"plotly_dashboard_ext/matrix/TCGA_low_pass/BRCA/",
+      load( url(paste0(paste0(baseurl,"matrix/TCGA_low_pass/BRCA/",
                               paste0(chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom1))))],chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom2))))],"melted_downsampled_TGCA_",sample_name,"_unrescaled",".RData")
       ))))
       ggplotmatrix_full<-ggplotmatrix
@@ -185,7 +212,7 @@ CNVScopeserver<-function(session,input, output) {
     if(isolate(input$data_source)=="TCGA_AML_low_pass")
     {
       sample_name<-"AML_output_matrix1e6"
-      load( url(paste0(paste0(baseurl,"plotly_dashboard_ext/matrix/TCGA_low_pass/AML/",
+      load( url(paste0(paste0(baseurl,"matrix/TCGA_low_pass/AML/",
                               paste0(chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom1))))],chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom2))))],"melted_downsampled_TGCA_",sample_name,"_unrescaled",".RData")
       ))))
       ggplotmatrix_full<-ggplotmatrix
@@ -193,7 +220,7 @@ CNVScopeserver<-function(session,input, output) {
     if(isolate(input$data_source)=="TCGA_PRAD_low_pass")
     {
       sample_name<-"PRAD_output_matrix1e6"
-      load( url(paste0(paste0(baseurl,"plotly_dashboard_ext/matrix/TCGA_low_pass/PRAD/",
+      load( url(paste0(paste0(baseurl,"matrix/TCGA_low_pass/PRAD/",
                               paste0(chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom1))))],chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom2))))],"melted_downsampled_TGCA_",sample_name,"_unrescaled",".RData")
       ))))
       ggplotmatrix_full<-ggplotmatrix
@@ -201,14 +228,14 @@ CNVScopeserver<-function(session,input, output) {
     if(isolate(input$data_source)=="TCGA_NBL_low_pass")
     {
       sample_name<-"NBL_output_matrix1e6"
-      load( url(paste0(paste0(baseurl,"plotly_dashboard_ext/matrix/TCGA_low_pass/NBL/",
+      load( paste0(paste0(basefn,"matrix/TCGA_low_pass/NBL/",
                               paste0(isolate(input$chrom1),isolate(input$chrom2),"nbl_sample_matched_unrescaled.RData")
-      ))))
+      )))
       #browser()
       #     ggplotmatrix
       ggplotmatrix_full<-ggplotmatrix
-      tryCatch(bin_data<<-readRDS((url(paste0(baseurl,"plotly_dashboard_ext/bin_data_nbl.rds")))),error = function(e) NULL) 
-      tryCatch(bin_data<<-readRDS((paste0(basefn,"plotly_dashboard_ext/bin_data_nbl.rds"))),error = function(e) NULL) 
+      tryCatch(bin_data<<-readRDS((url(paste0(baseurl,"bin_data_nbl.rds")))),error = function(e) NULL) 
+      tryCatch(bin_data<<-readRDS((paste0(basefn,"bin_data_nbl.rds"))),error = function(e) NULL) 
       
     }
     if(isolate(input$data_source) %in% c("TCGA_NBL_stage3_subset","TCGA_NBL_stage4_subset","TCGA_NBL_stage4s_subset","TCGA_NBL_myc_amp_subset","TCGA_NBL_not_myc_amp_subset"))
@@ -216,10 +243,10 @@ CNVScopeserver<-function(session,input, output) {
       #browser()
       subset_name<<-gsub("_subset","",gsub("TCGA_NBL_","",paste0(input$data_source)))
       sample_name<-"NBL_output_matrix1e6"
-      # load( url(paste0(paste0(baseurl,"plotly_dashboard_ext/matrix/TCGA_low_pass/NBL/",subset_name,"/",
+      # load( url(paste0(paste0(baseurl,"matrix/TCGA_low_pass/NBL/",subset_name,"/",
       #                         paste0(chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom1))))],chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom2))))],"melted_downsampled_TGCA_","NBLsample_matched","_unrescaled",subset_name,".RData")
       # ))))
-      load( url(paste0(paste0(baseurl,"plotly_dashboard_ext/matrix/TCGA_low_pass/NBL/",subset_name,"/",
+      load( url(paste0(paste0(baseurl,"matrix/TCGA_low_pass/NBL/",subset_name,"/",
                               paste0(isolate(input$chrom1),isolate(input$chrom2),"melted_downsampled_TGCA_","NBLsample_matched","_unrescaled",subset_name,"pos_neg.RData")
       ))))
       if(length(bin_data$probe)==0)
@@ -233,17 +260,17 @@ CNVScopeserver<-function(session,input, output) {
       
       #      ggplotmatrix
       ggplotmatrix_full<-ggplotmatrix
-      tryCatch(bin_data<<-readRDS((url(paste0(baseurl,"plotly_dashboard_ext/bin_data_nbl_",subset_name,".rds")))),error = function(e) NULL) 
-      tryCatch(bin_data<<-readRDS((paste0(basefn,"plotly_dashboard_ext/bin_data_nbl_",subset_name,".rds"))),error = function(e) NULL) 
+      tryCatch(bin_data<<-readRDS((url(paste0(baseurl,"bin_data_nbl_",subset_name,".rds")))),error = function(e) NULL) 
+      tryCatch(bin_data<<-readRDS((paste0(basefn,"bin_data_nbl_",subset_name,".rds"))),error = function(e) NULL) 
       #
-      tryCatch(expression_data_gr_nbl<<-readRDS(url(paste0(baseurl,"plotly_dashboard_ext/tcga_nbl_expression_",subset_name,"subset.rds"))),error = function(e) NULL)
-      tryCatch(expression_data_gr_nbl<<-readRDS(paste0(basefn,"plotly_dashboard_ext/tcga_nbl_expression_",subset_name,"subset.rds")),error = function(e) NULL)
+      tryCatch(expression_data_gr_nbl<<-readRDS(url(paste0(baseurl,"tcga_nbl_expression_",subset_name,"subset.rds"))),error = function(e) NULL)
+      tryCatch(expression_data_gr_nbl<<-readRDS(paste0(basefn,"tcga_nbl_expression_",subset_name,"subset.rds")),error = function(e) NULL)
       
       #server-side processing(disabled):
-      # tryCatch(tcga_gr<<-readRDS((url(paste0(baseurl,"plotly_dashboard_ext/tcga_gr_no_stats.rds")))),error = function(e) NULL) 
-      # tryCatch(tcga_gr<<-readRDS((paste0(basefn,"plotly_dashboard_ext/tcga_gr_no_stats.rds"))),error = function(e) NULL) 
-      # tryCatch(tcga_dfs_cbind_with_ensg_with_ensembl_fpkm<<-readRDS((url(paste0(baseurl,"plotly_dashboard_ext/tcga_dfs_cbind_with_ensg_with_ensembl_fpkm_caseid.rds")))),error = function(e) NULL) 
-      # tryCatch(tcga_dfs_cbind_with_ensg_with_ensembl_fpkm<<-readRDS((paste0(basefn,"plotly_dashboard_ext/tcga_dfs_cbind_with_ensg_with_ensembl_fpkm_caseid.rds"))),error = function(e) NULL) 
+      # tryCatch(tcga_gr<<-readRDS((url(paste0(baseurl,"tcga_gr_no_stats.rds")))),error = function(e) NULL) 
+      # tryCatch(tcga_gr<<-readRDS((paste0(basefn,"tcga_gr_no_stats.rds"))),error = function(e) NULL) 
+      # tryCatch(tcga_dfs_cbind_with_ensg_with_ensembl_fpkm<<-readRDS((url(paste0(baseurl,"tcga_dfs_cbind_with_ensg_with_ensembl_fpkm_caseid.rds")))),error = function(e) NULL) 
+      # tryCatch(tcga_dfs_cbind_with_ensg_with_ensembl_fpkm<<-readRDS((paste0(basefn,"tcga_dfs_cbind_with_ensg_with_ensembl_fpkm_caseid.rds"))),error = function(e) NULL) 
       # 
       # tcga_dfs_cbind_with_ensg_with_ensembl_fpkm_subset<-as.data.frame(tcga_dfs_cbind_with_ensg_with_ensembl_fpkm)[,na.omit(match(colnames(bin_data),colnames(tcga_dfs_cbind_with_ensg_with_ensembl_fpkm)))]
       # #dim(tcga_dfs_cbind_with_ensg_with_ensembl_fpkm_subset)
@@ -258,7 +285,7 @@ CNVScopeserver<-function(session,input, output) {
     if(isolate(input$data_source)=="TCGA_OS_low_pass")
     {
       sample_name<-"OS_output_matrix1e6"
-      load( url(paste0(paste0(baseurl,"plotly_dashboard_ext/matrix/TCGA_low_pass/OS/",
+      load( url(paste0(paste0(baseurl,"matrix/TCGA_low_pass/OS/",
                               paste0(chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom1))))],chromosomes[as.integer(gsub("_","",gsub("chr","",isolate(input$chrom2))))],"melted_downsampled_TGCA_",sample_name,"_unrescaled",".RData")
       ))))
       ggplotmatrix_full<-ggplotmatrix
@@ -302,6 +329,7 @@ CNVScopeserver<-function(session,input, output) {
     ggplotmatrix$value1<-gsub("row_genes:","col_genes:",ggplotmatrix$value1)
     rownames_ordered<-GRanges_to_underscored_pos(rownames_gr[order(rownames_gr)])
     colnames_ordered<-GRanges_to_underscored_pos(colnames_gr[order(colnames_gr)])
+   if(debug){browser()}
     recast_matrix<-recast_matrix[rownames_ordered,colnames_ordered]
     block_indices_row<-jointseg::jointSeg(recast_matrix,K=10,method="RBS")$bestBkp
     block_indices_col<-jointseg::jointSeg(t(recast_matrix),K=10,method="RBS")$bestBkp
@@ -326,18 +354,19 @@ CNVScopeserver<-function(session,input, output) {
                       fill=value,text=paste0("value:",value,"\nrow:",Var1,"\ncol:",Var2,"\n",value1))) +
       scale_x_continuous(breaks = reshape2::colsplit(block_index_labels_col,"_",c("chr","start","end"))$start,labels = block_index_labels_col) +
       scale_y_continuous(breaks = reshape2::colsplit(block_index_labels_row,"_",c("chr","start","end"))$start,labels = block_index_labels_row) + theme(axis.text.x = element_text(angle=60, hjust=1)) +  
-      ggplot2::scale_fill_gradient2(low = "blue", high = "red", midpoint = 0.5, limits = c(0, 1)) +  theme(legend.position="bottom",axis.title = element_blank()) #+ coord_flip() #+ scale_y_reverse(breaks=block_indices)
+      ggplot2::scale_fill_gradient2(low = "blue", high = "red", midpoint = 0.5, limits = c(0, 1)) +  theme(legend.position="bottom",axis.title = element_blank()) #+ geom_contour(binwidth = .395,aes(z=value))
+    #+ coord_flip() #+ scale_y_reverse(breaks=block_indices)
     #p
     #lumpy_points_toggle
     if(isolate(input$data_source)=="linreg_osteosarcoma_CNVkit")
     {
       if(exists("basefn"))
       {
-        tryCatch(SVs_data_in_submatrix_coords<-readRDS(paste0(basefn,"plotly_dashboard_ext/breakpoint_gint/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords.rds" )),error = function(e) NULL) 
-        tryCatch(lumpy_summarized_counts<-readRDS(paste0(basefn,"plotly_dashboard_ext/lumpy_sv/",gsub("_","",isolate(input$chrom1)),gsub("_","",isolate(input$chrom2)),"SVs_data_in_submatrix_coords_lumpy_mirror.rds" )),error = function(e) NULL)    
+        tryCatch(SVs_data_in_submatrix_coords<-readRDS(paste0(basefn,"breakpoint_gint/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords.rds" )),error = function(e) NULL) 
+        tryCatch(lumpy_summarized_counts<-readRDS(paste0(basefn,"lumpy_sv/",gsub("_","",isolate(input$chrom1)),gsub("_","",isolate(input$chrom2)),"SVs_data_in_submatrix_coords_lumpy_mirror.rds" )),error = function(e) NULL)    
       }else {
-        tryCatch(SVs_data_in_submatrix_coords<-readRDS(url(paste0(baseurl,"plotly_dashboard_ext/breakpoint_gint/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords.rds" ))),error = function(e) NULL) 
-        tryCatch(lumpy_summarized_counts<-readRDS(url(paste0(baseurl,"plotly_dashboard_ext/lumpy_sv/",gsub("_","",isolate(input$chrom1)),gsub("_","",isolate(input$chrom2)),"SVs_data_in_submatrix_coords_lumpy_mirror.rds" ))),error = function(e) NULL)   
+        tryCatch(SVs_data_in_submatrix_coords<-readRDS(url(paste0(baseurl,"breakpoint_gint/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords.rds" ))),error = function(e) NULL) 
+        tryCatch(lumpy_summarized_counts<-readRDS(url(paste0(baseurl,"lumpy_sv/",gsub("_","",isolate(input$chrom1)),gsub("_","",isolate(input$chrom2)),"SVs_data_in_submatrix_coords_lumpy_mirror.rds" ))),error = function(e) NULL)   
       }
       
     }
@@ -345,17 +374,17 @@ CNVScopeserver<-function(session,input, output) {
     {
       if(exists("basefn"))
       {
-        tryCatch(SVs_data_in_submatrix_coords<-readRDS(paste0(basefn,"plotly_dashboard_ext/breakpoint_gint/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_common_coords.rds" )),error = function(e) NULL)
-        tryCatch(lumpy_summarized_counts<-readRDS(paste0(basefn,"plotly_dashboard_ext/lumpy_sv/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_lumpy_mirror_TCGA_common_coords.rds" )),error = function(e) NULL)
+        tryCatch(SVs_data_in_submatrix_coords<-readRDS(paste0(basefn,"breakpoint_gint/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_common_coords.rds" )),error = function(e) NULL)
+        tryCatch(lumpy_summarized_counts<-readRDS(paste0(basefn,"lumpy_sv/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_lumpy_mirror_TCGA_common_coords.rds" )),error = function(e) NULL)
         tcga_type<<-gsub("_low_pass","",gsub("TCGA_","",isolate(input$data_source)))
-        tryCatch(TCGA_low_pass_sample_info<<-readRDS(paste0(basefn,"plotly_dashboard_ext/sample_info/",tcga_type,"TCGA_merged_dtv2.rds" )),error = function(e) NULL)
-        if(exists("TCGA_low_pass_sample_info")){TCGA_low_pass_sample_info$pos<-tidyr::unite(TCGA_low_pass_sample_info[,c(1:3)])}
+        tryCatch(TCGA_low_pass_sample_info<<-readRDS(paste0(basefn,"sample_info/",tcga_type,"TCGA_merged_dtv2.rds" )),error = function(e) NULL)
+        if(exists("TCGA_low_pass_sample_info")){TCGA_low_pass_sample_info$pos<- tidyr::unite(TCGA_low_pass_sample_info,pos,bins.seqnames,bins.start,bins.end)$pos}
       } else {
-        tryCatch(SVs_data_in_submatrix_coords<-readRDS(url(paste0(baseurl,"plotly_dashboard_ext/breakpoint_gint/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_common_coords.rds" ))),error = function(e) NULL)
-        tryCatch(lumpy_summarized_counts<-readRDS(url(paste0(baseurl,"plotly_dashboard_ext/lumpy_sv/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_lumpy_mirror_TCGA_common_coords.rds" ))),error = function(e) NULL)
+        tryCatch(SVs_data_in_submatrix_coords<-readRDS(url(paste0(baseurl,"breakpoint_gint/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_common_coords.rds" ))),error = function(e) NULL)
+        tryCatch(lumpy_summarized_counts<-readRDS(url(paste0(baseurl,"lumpy_sv/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_lumpy_mirror_TCGA_common_coords.rds" ))),error = function(e) NULL)
         tcga_type<<-gsub("_low_pass","",gsub("TCGA_","",isolate(input$data_source)))
-        tryCatch(TCGA_low_pass_sample_info<<-readRDS(url(paste0(baseurl,"plotly_dashboard_ext/sample_info/",tcga_type,"TCGA_merged_dtv2.rds" ))),error = function(e) NULL)
-        if(exists("TCGA_low_pass_sample_info")){TCGA_low_pass_sample_info$pos<-tidyr::unite(TCGA_low_pass_sample_info[,c(1:3)])}
+        tryCatch(TCGA_low_pass_sample_info<<-readRDS(url(paste0(baseurl,"sample_info/",tcga_type,"TCGA_merged_dtv2.rds" ))),error = function(e) NULL)
+        if(exists("TCGA_low_pass_sample_info")){TCGA_low_pass_sample_info$pos<- tidyr::unite(TCGA_low_pass_sample_info,pos,bins.seqnames,bins.start,bins.end)$pos}
       }
     }
     if(isolate(input$data_source) %in% c("TCGA_NBL_stage3_subset","TCGA_NBL_stage4_subset","TCGA_NBL_stage4s_subset","TCGA_NBL_myc_amp_subset","TCGA_NBL_not_myc_amp_subset"))
@@ -363,17 +392,17 @@ CNVScopeserver<-function(session,input, output) {
       subset_name<<-gsub("_subset","",gsub("TCGA_NBL_","",paste0(input$data_source)))
       if(exists("basefn"))
       {
-        tryCatch(SVs_data_in_submatrix_coords<-readRDS(paste0(basefn,"plotly_dashboard_ext/breakpoint_gint/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_common_coords.rds" )),error = function(e) NULL)
-        tryCatch(lumpy_summarized_counts<-readRDS(paste0(basefn,"plotly_dashboard_ext/lumpy_sv/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_lumpy_mirror_TCGA_common_coords.rds" )),error = function(e) NULL)
+        tryCatch(SVs_data_in_submatrix_coords<-readRDS(paste0(basefn,"breakpoint_gint/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_common_coords.rds" )),error = function(e) NULL)
+        tryCatch(lumpy_summarized_counts<-readRDS(paste0(basefn,"lumpy_sv/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_lumpy_mirror_TCGA_common_coords.rds" )),error = function(e) NULL)
         tcga_type<<-gsub("_low_pass","",gsub("TCGA_","",isolate(input$data_source)))
-        tryCatch(TCGA_low_pass_sample_info<<-readRDS(paste0(basefn,"plotly_dashboard_ext/sample_info/",tcga_type,"TCGA_merged_dtv2.rds" )),error = function(e) NULL)
-        if(exists("TCGA_low_pass_sample_info")){TCGA_low_pass_sample_info$pos<-tidyr::unite(TCGA_low_pass_sample_info[,c(1:3)])}
+        tryCatch(TCGA_low_pass_sample_info<<-readRDS(paste0(basefn,"sample_info/",tcga_type,"TCGA_merged_dtv2.rds" )),error = function(e) NULL)
+        if(exists("TCGA_low_pass_sample_info")){TCGA_low_pass_sample_info$pos<- tidyr::unite(TCGA_low_pass_sample_info,pos,bins.seqnames,bins.start,bins.end)$pos}
       } else {
-        tryCatch(SVs_data_in_submatrix_coords<-readRDS(url(paste0(baseurl,"plotly_dashboard_ext/breakpoint_gint/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_common_coords.rds" ))),error = function(e) NULL)
-        tryCatch(lumpy_summarized_counts<-readRDS(url(paste0(baseurl,"plotly_dashboard_ext/lumpy_sv/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_lumpy_mirror_TCGA_common_coords.rds" ))),error = function(e) NULL)
+        tryCatch(SVs_data_in_submatrix_coords<-readRDS(url(paste0(baseurl,"breakpoint_gint/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_common_coords.rds" ))),error = function(e) NULL)
+        tryCatch(lumpy_summarized_counts<-readRDS(url(paste0(baseurl,"lumpy_sv/TCGA_low_pass/",isolate(input$chrom1),isolate(input$chrom2),"SVs_data_in_submatrix_coords_lumpy_mirror_TCGA_common_coords.rds" ))),error = function(e) NULL)
         tcga_type<<-gsub("_low_pass","",gsub("TCGA_","",isolate(input$data_source)))
-        tryCatch(TCGA_low_pass_sample_info<<-readRDS(url(paste0(baseurl,"plotly_dashboard_ext/sample_info/",tcga_type,"TCGA_merged_dtv2.rds" ))),error = function(e) NULL)
-        if(exists("TCGA_low_pass_sample_info")){TCGA_low_pass_sample_info$pos<-tidyr::unite(TCGA_low_pass_sample_info[,c(1:3)])}
+        tryCatch(TCGA_low_pass_sample_info<<-readRDS(url(paste0(baseurl,"sample_info/",tcga_type,"TCGA_merged_dtv2.rds" ))),error = function(e) NULL)
+        if(exists("TCGA_low_pass_sample_info")){TCGA_low_pass_sample_info$pos<- tidyr::unite(TCGA_low_pass_sample_info,pos,bins.seqnames,bins.start,bins.end)$pos}
       }
     }
     
@@ -478,7 +507,7 @@ CNVScopeserver<-function(session,input, output) {
     
     #                                      scale_colour_gradient2()
     #set the range to be specific if there are coordinates (the cell +/- 4), else choose the max range for the particular axis.
-    browser()
+   if(debug){browser()}
     
     
     #check for the correct format.
@@ -493,9 +522,9 @@ CNVScopeserver<-function(session,input, output) {
     #plotly_output<-plotly::ggplotly(p) %>%       layout(margin=list(r=0, l=200, t=0, b=200),width=1280,height=1024)
     #%>% saveWidget(title = gsub("_","",paste0(chromosomes[isolate(input$chrom1)],"-",chromosomes[isolate(input$chrom2)])),file = paste0(chromosomes[isolate(input$chrom1)],chromosomes[isolate(input$chrom2)],"transparent_tooltipv27_coord_no_flip_downsample_upward_orientation_plotly_nrsample.html"),selfcontained = T)
     #
-    if(!is.null(isolate(input$loc_input_row)) | !is.null(isolate(input$loc_input_col)))
+    if( (!is.null(isolate(input$loc_input_row)) | !is.null(isolate(input$loc_input_col)) ) & (!isolate(input$loc_input_row)=="" | !isolate(input$loc_input_col)==""))
     {
-      browser()
+     if(debug){browser()}
       #acknowledgement: thanks to stackoverflow comments that made package a reality.
       #find the location of the bin in terms of map coordinates for x
       #store this as the xcentercoord
@@ -544,7 +573,7 @@ CNVScopeserver<-function(session,input, output) {
       return(plotly_output)
     } else {}
     
-    browser()
+   if(debug){browser()}
     print(plotly_output)
   })
   outputOptions(output,"plotlyChromosomalHeatmap",suspendWhenHidden=F)
@@ -610,14 +639,23 @@ CNVScopeserver<-function(session,input, output) {
       #
       #rowclick<-length(common_coords)-myReactives$currentClick$lat
       #colclick<-myReactives$currentClick$lng
+     if(debug){browser()}
       rowexpression<-as.data.table(subsetByOverlaps(expression_data_gr,get_rownames_gr_full()[seq(from=row_index_full,to=row_index_full+3)]))
       colexpression<-as.data.table(subsetByOverlaps(expression_data_gr,get_colnames_gr_full()[seq(from=col_index_full,to=col_index_full+3)]))} else {
         if(isolate(input$data_source)=="TCGA_NBL_low_pass" | isolate(input$data_source) %in% c("TCGA_NBL_stage3_subset","TCGA_NBL_stage4_subset","TCGA_NBL_stage4s_subset","TCGA_NBL_myc_amp_subset","TCGA_NBL_not_myc_amp_subset"))
         {
+          
+if(debug){browser()}
           rownames_gr_full<-get_rownames_gr_full()
           colnames_gr_full<-get_colnames_gr_full()
+#         if(!exists("expression_data_gr_nbl")){
+            tryCatch(expression_data_gr_nbl<-readRDS(paste0(get("basefn",.GlobalEnv),"tcga_nbl_expression.rds")),error = function(e) NULL)  
+ #         }
+          if(length(expression_data_gr_nbl)==0){
+          tryCatch(expression_data_gr_nbl<-readRDS(paste0(get("basefn",.GlobalEnv),"tcga_nbl_expression.rds")),error = function(e) NULL)
+            }
           #mcols(expression_data_gr_nbl)$SYMBOL<-expression_data_gr_nbl$....external_gene_name
-          
+         if(debug){browser()}
           rowexpression<-as.data.table(subsetByOverlaps(expression_data_gr_nbl,rownames_gr_full[rownames_gr_full@ranges@start==event_data("plotly_click")[["y"]]]))
           colexpression<-as.data.table(subsetByOverlaps(expression_data_gr_nbl,colnames_gr_full[colnames_gr_full@ranges@start==event_data("plotly_click")[["x"]]]))
         }
@@ -639,6 +677,7 @@ CNVScopeserver<-function(session,input, output) {
     #
     if(is.null(event_data("plotly_click"))){return(data.table())}
     recast_matrix<-get_recast_matrix()
+    if(length(intersect(ls(),"census_data_gr"))!=1) {    tryCatch(census_data_gr<-readRDS(paste0(basefn,"censushg19.rds")),error = function(e) NULL)}
     row_label<-rownames(recast_matrix)[as.integer(paste0(event_data("plotly_click")[["pointNumber"]][[1]][1]))+1] #correct column label.
     column_label<-colnames(recast_matrix)[as.integer(paste0(event_data("plotly_click")[["pointNumber"]][[1]][2]))+1] #correct column label.
     #row_point_gr<-underscored_pos_to_GRanges(row_label)
@@ -849,8 +888,6 @@ CNVScopeserver<-function(session,input, output) {
       row_labels_minimap<-rownames(recast_matrix_full)[grep(row_label,rownames(recast_matrix_full)):(grep(row_label,rownames(recast_matrix_full))+3)] #we subset by every fourth number along the rows and columns, hence we need n, n+1, n+2, n+3 (or n1:n2-1, the first number and all the numbers leading up to the next).
       col_labels_minimap<-colnames(recast_matrix_full)[grep(column_label,colnames(recast_matrix_full)):(grep(column_label,colnames(recast_matrix_full))+3)]
       ggplotmatrix_minimap<-ggplotmatrix_full[as.character(ggplotmatrix_full$Var1) %in% row_labels_minimap & as.character(ggplotmatrix_full$Var2) %in% col_labels_minimap, ]
-      
-      #browser()
       p <- ggplot(data = ggplotmatrix_minimap ) + #geom_tile() + theme_void()
         geom_raster(aes(x = Var2, y = Var1,fill=value,text=paste0("value:",value,"\nrow:",Var1,"\ncol:",Var2,"\n",value1))) + scale_x_discrete() +
         scale_y_discrete() + theme(axis.text.x = element_text(angle=60, hjust=1)) + 
